from setuptools import setup

setup(
    name = 'recat',
    version = '0.1',
    packages = [],
    author = 'Andrew Gwozdziewycz',
    author_email = 'web@apgwoz.com',
    description = 'Replay log files simply and easily',
    license = 'GPLv3',
    keywords = 'log replay',
    url = 'https://github.com/apgwoz/recat',
    scripts = ['recat']
)
